@@ -1,9 +1,9 @@
 /*
  * security/ccsecurity/network.c
  *
- * Copyright (C) 2005-2010  NTT DATA CORPORATION
+ * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.7.2   2010/04/01
+ * Version: 1.7.3+   2012/05/05
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -75,7 +75,8 @@ int ccs_parse_ip_address(char *address, u16 *min, u16 *max)
 			       + (((u8) min[2]) << 8) + (u8) min[3]);
 		memmove(min, &ip, sizeof(ip));
 		if (count == 8)
-			ip = htonl((((u8) max[0]) << 24) + (((u8) max[1]) << 16)
+			ip = htonl((((u8) max[0]) << 24)
+				   + (((u8) max[1]) << 16)
 				   + (((u8) max[2]) << 8) + (u8) max[3]);
 		memmove(max, &ip, sizeof(ip));
 		return 1;
@@ -169,8 +170,8 @@ static int ccs_network_entry2(const bool is_ipv6, const u8 operation,
 	const u32 ip = ntohl(*address);
 	int error;
 	char buf[64];
-	if (ccs_init_request_info(&r, NULL,
-				  CCS_MAC_NETWORK_UDP_BIND + operation)
+	const struct ccs_domain_info * const domain = ccs_current_domain();
+	if (ccs_init_request_info(&r, CCS_MAC_NETWORK_UDP_BIND + operation)
 	    == CCS_CONFIG_DISABLED)
 		return 0;
 	memset(buf, 0, sizeof(buf));
@@ -181,7 +182,7 @@ static int ccs_network_entry2(const bool is_ipv6, const u8 operation,
 		snprintf(buf, sizeof(buf) - 1, "%u.%u.%u.%u", HIPQUAD(ip));
 	do {
 		error = -EPERM;
-		list_for_each_entry_rcu(ptr, &r.domain->acl_info_list, list) {
+		list_for_each_entry_rcu(ptr, &domain->acl_info_list, list) {
 			struct ccs_ip_network_acl *acl;
 			if (ptr->is_deleted ||
 			    ptr->type != CCS_TYPE_IP_NETWORK_ACL)
@@ -522,6 +523,14 @@ static inline int ccs_network_recvmsg_acl(const bool is_ipv6,
 	return retval;
 }
 
+#ifndef CONFIG_NET
+
+void __init ccs_network_init(void)
+{
+}
+
+#else
+
 #define MAX_SOCK_ADDR 128 /* net/socket.c */
 
 /* Check permission for creating a socket. */
@@ -811,7 +820,7 @@ static inline struct ipv6hdr *ipv6_hdr(const struct sk_buff *skb)
 #endif
 #endif
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 12)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 5, 0)
 static void skb_kill_datagram(struct sock *sk, struct sk_buff *skb,
 			      unsigned int flags)
 {
@@ -906,15 +915,30 @@ static int __ccs_socket_recvmsg_permission(struct sock *sk,
 	 * prevent the caller from picking up next message from wanted source
 	 * when the caller is using MSG_PEEK flag for picking up.
 	 */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 25)
-	if (type == SOCK_DGRAM)
-		lock_sock(sk);
+	{
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 35)
+		bool slow = false;
+		if (type == SOCK_DGRAM)
+			slow = lock_sock_fast(sk);
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 25)
+		if (type == SOCK_DGRAM)
+			lock_sock(sk);
+#elif defined(RHEL_MAJOR) && RHEL_MAJOR == 5 && defined(RHEL_MINOR) && RHEL_MINOR >= 2
+		if (type == SOCK_DGRAM && family != PF_UNIX)
+			lock_sock(sk);
 #endif
-	skb_kill_datagram(sk, skb, flags);
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 25)
-	if (type == SOCK_DGRAM)
-		release_sock(sk);
+		skb_kill_datagram(sk, skb, flags);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 35)
+		if (type == SOCK_DGRAM)
+			unlock_sock_fast(sk, slow);
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 25)
+		if (type == SOCK_DGRAM)
+			release_sock(sk);
+#elif defined(RHEL_MAJOR) && RHEL_MAJOR == 5 && defined(RHEL_MINOR) && RHEL_MINOR >= 2
+		if (type == SOCK_DGRAM && family != PF_UNIX)
+			release_sock(sk);
 #endif
+	}
 	/* Hope less harmful than -EPERM. */
 	return -ENOMEM;
 }
@@ -935,3 +959,5 @@ void __init ccs_network_init(void)
 	ccsecurity_ops.socket_recvmsg_permission =
 		__ccs_socket_recvmsg_permission;
 }
+
+#endif
