@@ -1,9 +1,9 @@
 /*
  * security/ccsecurity/realpath.c
  *
- * Copyright (C) 2005-2009  NTT DATA CORPORATION
+ * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.7.1+   2009/12/20
+ * Version: 1.7.3+   2012/05/05
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -113,7 +113,7 @@ static char *ccs_get_absolute_path(struct path *path, char * const buffer,
 				len = 4;
 			}
 #else
-			if (!*ep && pid == sys_getpid()) {
+			if (!*ep && pid == ccsecurity_exports.sys_getpid()) {
 				name = "self";
 				len = 4;
 			}
@@ -162,7 +162,7 @@ char *ccs_realpath_from_path(struct path *path)
 		char *pos;
 		buf_len <<= 1;
 		kfree(buf);
-		buf = kmalloc(buf_len, GFP_KERNEL);
+		buf = kmalloc(buf_len, CCS_GFP_FLAGS);
 		if (!buf)
 			break;
 		/* Get better name for socket. */
@@ -285,7 +285,7 @@ char *ccs_encode(const char *str)
 	}
 	len++;
 	/* Reserve space for appending "/". */
-	cp = kzalloc(len + 10, GFP_KERNEL);
+	cp = kzalloc(len + 10, CCS_GFP_FLAGS);
 	if (!cp)
 		return NULL;
 	cp0 = cp;
